# Generated by Django 3.2.10 on 2022-04-20 12:39

from django.db import migrations, models
import django.db.models.deletion
"""
Migration script to move foreign keys in Settings and WorkoutLog from
Exercise to ExerciseBase. We first add a nullable FK to ExerciseBase,
then we migrate the data.
"""


def migrate_setting_to_exercise_base(apps, schema_editor):
    Setting = apps.get_model('manager', 'Setting')

    settings = Setting.objects.all()
    for setting in settings:
        setting.exercise_base = setting.exercise.exercise_base
    Setting.objects.bulk_update(settings, ['exercise_base'], batch_size=1000)


def migrate_log_to_exercise_base(apps, schema_editor):
    WorkoutLog = apps.get_model('manager', 'WorkoutLog')

    logs = WorkoutLog.objects.all()
    for log in logs:
        log.exercise_base = log.exercise.exercise_base
    WorkoutLog.objects.bulk_update(logs, ['exercise_base'], batch_size=1000)


class Migration(migrations.Migration):

    dependencies = [
        ('exercises', '0019_exercise_crowdsourcing_changes'),
        ('manager', '0015_auto_20211028_1113'),
    ]

    operations = [
        # Settings
        migrations.AddField(
            model_name='setting',
            name='exercise_base',
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to='exercises.exercisebase',
                verbose_name='Exercises'
            ),
        ),
        migrations.RunPython(migrate_setting_to_exercise_base),
        migrations.AlterField(
            model_name='setting',
            name='exercise_base',
            field=models.ForeignKey(
                null=False,
                on_delete=django.db.models.deletion.CASCADE,
                to='exercises.exercisebase',
                verbose_name='Exercises'
            ),
        ),
        migrations.RemoveField(
            model_name='setting',
            name='exercise',
        ),

        # WorkoutLog
        migrations.AddField(
            model_name='workoutlog',
            name='exercise_base',
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to='exercises.exercisebase',
                verbose_name='Exercises'
            ),
        ),
        migrations.RunPython(migrate_log_to_exercise_base),
        migrations.AlterField(
            model_name='workoutlog',
            name='exercise_base',
            field=models.ForeignKey(
                null=False,
                on_delete=django.db.models.deletion.CASCADE,
                to='exercises.exercisebase',
                verbose_name='Exercises'
            ),
        ),
        migrations.RemoveField(
            model_name='workoutlog',
            name='exercise',
        ),
    ]
